LinchPin Command-Line API
==========================

The linchpin.cli module provides an API for writing a command-line interface,
the :doc:`libshell` being the reference implementation.

.. automodule:: linchpin.cli
    :members:
    :undoc-members:

.. automodule:: linchpin.cli.context
    :members:
    :undoc-members:
